==> kubernetes-model-flowcontrol-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/SubjectFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubjectFluentImpl<A extends SubjectFluent<A>> extends BaseFluent<A> implements SubjectFluent<A>{
  public SubjectFluentImpl() {
  }
  public SubjectFluentImpl(Subject instance) {
    this.withGroup(instance.getGroup()); 
    this.withKind(instance.getKind()); 
    this.withServiceAccount(instance.getServiceAccount()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private GroupSubjectBuilder group;
  private String kind;
  private ServiceAccountSubjectBuilder serviceAccount;
  private UserSubjectBuilder user;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildGroup instead.
   * @return The buildable object.
   */
  @Deprecated
  public GroupSubject getGroup() {
    return this.group!=null ?this.group.build():null;
  }
  public GroupSubject buildGroup() {
    return this.group!=null ?this.group.build():null;
  }
  public A withGroup(GroupSubject group) {
    _visitables.get("group").remove(this.group);
    if (group!=null){ this.group= new GroupSubjectBuilder(group); _visitables.get("group").add(this.group);} else { this.group = null; _visitables.get("group").remove(this.group); } return (A) this;
  }
  public Boolean hasGroup() {
    return this.group != null;
  }
  public A withNewGroup(String name) {
    return (A)withGroup(new GroupSubject(name));
  }
  public SubjectFluent.GroupNested<A> withNewGroup() {
    return new SubjectFluentImpl.GroupNestedImpl();
  }
  public SubjectFluent.GroupNested<A> withNewGroupLike(GroupSubject item) {
    return new SubjectFluentImpl.GroupNestedImpl(item);
  }
  public SubjectFluent.GroupNested<A> editGroup() {
    return withNewGroupLike(getGroup());
  }
  public SubjectFluent.GroupNested<A> editOrNewGroup() {
    return withNewGroupLike(getGroup() != null ? getGroup(): new GroupSubjectBuilder().build());
  }
  public SubjectFluent.GroupNested<A> editOrNewGroupLike(GroupSubject item) {
    return withNewGroupLike(getGroup() != null ? getGroup(): item);
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildServiceAccount instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceAccountSubject getServiceAccount() {
    return this.serviceAccount!=null ?this.serviceAccount.build():null;
  }
  public ServiceAccountSubject buildServiceAccount() {
    return this.serviceAccount!=null ?this.serviceAccount.build():null;
  }
  public A withServiceAccount(ServiceAccountSubject serviceAccount) {
    _visitables.get("serviceAccount").remove(this.serviceAccount);
    if (serviceAccount!=null){ this.serviceAccount= new ServiceAccountSubjectBuilder(serviceAccount); _visitables.get("serviceAccount").add(this.serviceAccount);} else { this.serviceAccount = null; _visitables.get("serviceAccount").remove(this.serviceAccount); } return (A) this;
  }
  public Boolean hasServiceAccount() {
    return this.serviceAccount != null;
  }
  public A withNewServiceAccount(String name,String namespace) {
    return (A)withServiceAccount(new ServiceAccountSubject(name, namespace));
  }
  public SubjectFluent.ServiceAccountNested<A> withNewServiceAccount() {
    return new SubjectFluentImpl.ServiceAccountNestedImpl();
  }
  public SubjectFluent.ServiceAccountNested<A> withNewServiceAccountLike(ServiceAccountSubject item) {
    return new SubjectFluentImpl.ServiceAccountNestedImpl(item);
  }
  public SubjectFluent.ServiceAccountNested<A> editServiceAccount() {
    return withNewServiceAccountLike(getServiceAccount());
  }
  public SubjectFluent.ServiceAccountNested<A> editOrNewServiceAccount() {
    return withNewServiceAccountLike(getServiceAccount() != null ? getServiceAccount(): new ServiceAccountSubjectBuilder().build());
  }
  public SubjectFluent.ServiceAccountNested<A> editOrNewServiceAccountLike(ServiceAccountSubject item) {
    return withNewServiceAccountLike(getServiceAccount() != null ? getServiceAccount(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildUser instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserSubject getUser() {
    return this.user!=null ?this.user.build():null;
  }
  public UserSubject buildUser() {
    return this.user!=null ?this.user.build():null;
  }
  public A withUser(UserSubject user) {
    _visitables.get("user").remove(this.user);
    if (user!=null){ this.user= new UserSubjectBuilder(user); _visitables.get("user").add(this.user);} else { this.user = null; _visitables.get("user").remove(this.user); } return (A) this;
  }
  public Boolean hasUser() {
    return this.user != null;
  }
  public A withNewUser(String name) {
    return (A)withUser(new UserSubject(name));
  }
  public SubjectFluent.UserNested<A> withNewUser() {
    return new SubjectFluentImpl.UserNestedImpl();
  }
  public SubjectFluent.UserNested<A> withNewUserLike(UserSubject item) {
    return new SubjectFluentImpl.UserNestedImpl(item);
  }
  public SubjectFluent.UserNested<A> editUser() {
    return withNewUserLike(getUser());
  }
  public SubjectFluent.UserNested<A> editOrNewUser() {
    return withNewUserLike(getUser() != null ? getUser(): new UserSubjectBuilder().build());
  }
  public SubjectFluent.UserNested<A> editOrNewUserLike(UserSubject item) {
    return withNewUserLike(getUser() != null ? getUser(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubjectFluentImpl that = (SubjectFluentImpl) o;
    if (group != null ? !group.equals(that.group) :that.group != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (serviceAccount != null ? !serviceAccount.equals(that.serviceAccount) :that.serviceAccount != null) return false;
    if (user != null ? !user.equals(that.user) :that.user != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  kind,  serviceAccount,  user,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (serviceAccount != null) { sb.append("serviceAccount:"); sb.append(serviceAccount + ","); }
    if (user != null) { sb.append("user:"); sb.append(user + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class GroupNestedImpl<N> extends GroupSubjectFluentImpl<SubjectFluent.GroupNested<N>> implements SubjectFluent.GroupNested<N>,Nested<N>{
    GroupNestedImpl(GroupSubject item) {
      this.builder = new GroupSubjectBuilder(this, item);
    }
    GroupNestedImpl() {
      this.builder = new GroupSubjectBuilder(this);
    }
    GroupSubjectBuilder builder;
    public N and() {
      return (N) SubjectFluentImpl.this.withGroup(builder.build());
    }
    public N endGroup() {
      return and();
    }
    
  }
  class ServiceAccountNestedImpl<N> extends ServiceAccountSubjectFluentImpl<SubjectFluent.ServiceAccountNested<N>> implements SubjectFluent.ServiceAccountNested<N>,Nested<N>{
    ServiceAccountNestedImpl(ServiceAccountSubject item) {
      this.builder = new ServiceAccountSubjectBuilder(this, item);
    }
    ServiceAccountNestedImpl() {
      this.builder = new ServiceAccountSubjectBuilder(this);
    }
    ServiceAccountSubjectBuilder builder;
    public N and() {
      return (N) SubjectFluentImpl.this.withServiceAccount(builder.build());
    }
    public N endServiceAccount() {
      return and();
    }
    
  }
  class UserNestedImpl<N> extends UserSubjectFluentImpl<SubjectFluent.UserNested<N>> implements SubjectFluent.UserNested<N>,Nested<N>{
    UserNestedImpl(UserSubject item) {
      this.builder = new UserSubjectBuilder(this, item);
    }
    UserNestedImpl() {
      this.builder = new UserSubjectBuilder(this);
    }
    UserSubjectBuilder builder;
    public N and() {
      return (N) SubjectFluentImpl.this.withUser(builder.build());
    }
    public N endUser() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/SubjectFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubjectFluentImpl<A extends SubjectFluent<A>> extends BaseFluent<A> implements SubjectFluent<A>{
  public SubjectFluentImpl() {
  }
  public SubjectFluentImpl(Subject instance) {
    if (instance != null) {
      this.withGroup(instance.getGroup());
      this.withKind(instance.getKind());
      this.withServiceAccount(instance.getServiceAccount());
      this.withUser(instance.getUser());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private GroupSubjectBuilder group;
  private String kind;
  private ServiceAccountSubjectBuilder serviceAccount;
  private UserSubjectBuilder user;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildGroup instead.
   * @return The buildable object.
   */
  @Deprecated
  public GroupSubject getGroup() {
    return this.group!=null ?this.group.build():null;
  }
  public GroupSubject buildGroup() {
    return this.group!=null ?this.group.build():null;
  }
  public A withGroup(GroupSubject group) {
    _visitables.get("group").remove(this.group);
    if (group!=null){ this.group= new GroupSubjectBuilder(group); _visitables.get("group").add(this.group);} else { this.group = null; _visitables.get("group").remove(this.group); } return (A) this;
  }
  public Boolean hasGroup() {
    return this.group != null;
  }
  public A withNewGroup(String name) {
    return (A)withGroup(new GroupSubject(name));
  }
  public SubjectFluentImpl.GroupNested<A> withNewGroup() {
    return new SubjectFluentImpl.GroupNestedImpl();
  }
  public SubjectFluentImpl.GroupNested<A> withNewGroupLike(GroupSubject item) {
    return new SubjectFluentImpl.GroupNestedImpl(item);
  }
  public SubjectFluentImpl.GroupNested<A> editGroup() {
    return withNewGroupLike(getGroup());
  }
  public SubjectFluentImpl.GroupNested<A> editOrNewGroup() {
    return withNewGroupLike(getGroup() != null ? getGroup(): new GroupSubjectBuilder().build());
  }
  public SubjectFluentImpl.GroupNested<A> editOrNewGroupLike(GroupSubject item) {
    return withNewGroupLike(getGroup() != null ? getGroup(): item);
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildServiceAccount instead.
   * @return The buildable object.
   */
  @Deprecated
  public ServiceAccountSubject getServiceAccount() {
    return this.serviceAccount!=null ?this.serviceAccount.build():null;
  }
  public ServiceAccountSubject buildServiceAccount() {
    return this.serviceAccount!=null ?this.serviceAccount.build():null;
  }
  public A withServiceAccount(ServiceAccountSubject serviceAccount) {
    _visitables.get("serviceAccount").remove(this.serviceAccount);
    if (serviceAccount!=null){ this.serviceAccount= new ServiceAccountSubjectBuilder(serviceAccount); _visitables.get("serviceAccount").add(this.serviceAccount);} else { this.serviceAccount = null; _visitables.get("serviceAccount").remove(this.serviceAccount); } return (A) this;
  }
  public Boolean hasServiceAccount() {
    return this.serviceAccount != null;
  }
  public A withNewServiceAccount(String name,String namespace) {
    return (A)withServiceAccount(new ServiceAccountSubject(name, namespace));
  }
  public SubjectFluentImpl.ServiceAccountNested<A> withNewServiceAccount() {
    return new SubjectFluentImpl.ServiceAccountNestedImpl();
  }
  public SubjectFluentImpl.ServiceAccountNested<A> withNewServiceAccountLike(ServiceAccountSubject item) {
    return new SubjectFluentImpl.ServiceAccountNestedImpl(item);
  }
  public SubjectFluentImpl.ServiceAccountNested<A> editServiceAccount() {
    return withNewServiceAccountLike(getServiceAccount());
  }
  public SubjectFluentImpl.ServiceAccountNested<A> editOrNewServiceAccount() {
    return withNewServiceAccountLike(getServiceAccount() != null ? getServiceAccount(): new ServiceAccountSubjectBuilder().build());
  }
  public SubjectFluentImpl.ServiceAccountNested<A> editOrNewServiceAccountLike(ServiceAccountSubject item) {
    return withNewServiceAccountLike(getServiceAccount() != null ? getServiceAccount(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildUser instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserSubject getUser() {
    return this.user!=null ?this.user.build():null;
  }
  public UserSubject buildUser() {
    return this.user!=null ?this.user.build():null;
  }
  public A withUser(UserSubject user) {
    _visitables.get("user").remove(this.user);
    if (user!=null){ this.user= new UserSubjectBuilder(user); _visitables.get("user").add(this.user);} else { this.user = null; _visitables.get("user").remove(this.user); } return (A) this;
  }
  public Boolean hasUser() {
    return this.user != null;
  }
  public A withNewUser(String name) {
    return (A)withUser(new UserSubject(name));
  }
  public SubjectFluentImpl.UserNested<A> withNewUser() {
    return new SubjectFluentImpl.UserNestedImpl();
  }
  public SubjectFluentImpl.UserNested<A> withNewUserLike(UserSubject item) {
    return new SubjectFluentImpl.UserNestedImpl(item);
  }
  public SubjectFluentImpl.UserNested<A> editUser() {
    return withNewUserLike(getUser());
  }
  public SubjectFluentImpl.UserNested<A> editOrNewUser() {
    return withNewUserLike(getUser() != null ? getUser(): new UserSubjectBuilder().build());
  }
  public SubjectFluentImpl.UserNested<A> editOrNewUserLike(UserSubject item) {
    return withNewUserLike(getUser() != null ? getUser(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubjectFluentImpl that = (SubjectFluentImpl) o;
    if (!java.util.Objects.equals(group, that.group)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(serviceAccount, that.serviceAccount)) return false;

    if (!java.util.Objects.equals(user, that.user)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  kind,  serviceAccount,  user,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (serviceAccount != null) { sb.append("serviceAccount:"); sb.append(serviceAccount + ","); }
    if (user != null) { sb.append("user:"); sb.append(user + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class GroupNestedImpl<N> extends GroupSubjectFluentImpl<SubjectFluentImpl.GroupNested<N>> implements SubjectFluentImpl.GroupNested<N>,Nested<N>{
    GroupNestedImpl(GroupSubject item) {
      this.builder = new GroupSubjectBuilder(this, item);
    }
    GroupNestedImpl() {
      this.builder = new GroupSubjectBuilder(this);
    }
    GroupSubjectBuilder builder;
    public N and() {
      return (N) SubjectFluentImpl.this.withGroup(builder.build());
    }
    public N endGroup() {
      return and();
    }
    
  }
  class ServiceAccountNestedImpl<N> extends ServiceAccountSubjectFluentImpl<SubjectFluentImpl.ServiceAccountNested<N>> implements SubjectFluentImpl.ServiceAccountNested<N>,Nested<N>{
    ServiceAccountNestedImpl(ServiceAccountSubject item) {
      this.builder = new ServiceAccountSubjectBuilder(this, item);
    }
    ServiceAccountNestedImpl() {
      this.builder = new ServiceAccountSubjectBuilder(this);
    }
    ServiceAccountSubjectBuilder builder;
    public N and() {
      return (N) SubjectFluentImpl.this.withServiceAccount(builder.build());
    }
    public N endServiceAccount() {
      return and();
    }
    
  }
  class UserNestedImpl<N> extends UserSubjectFluentImpl<SubjectFluentImpl.UserNested<N>> implements SubjectFluentImpl.UserNested<N>,Nested<N>{
    UserNestedImpl(UserSubject item) {
      this.builder = new UserSubjectBuilder(this, item);
    }
    UserNestedImpl() {
      this.builder = new UserSubjectBuilder(this);
    }
    UserSubjectBuilder builder;
    public N and() {
      return (N) SubjectFluentImpl.this.withUser(builder.build());
    }
    public N endUser() {
      return and();
    }
    
  }
  
}
